
From: Chris Zankel <czankel@tensilica.com>

This patch fixes some minor bugs introduced by the previous patch (remove
old syscalls).  Both patches remove the obsolete syscalls.  The changes in
this patch were suggested by Arnd Bergmann.  The vmlinux.lds.S changes are
required for the latest gcc/binutils.

Signed-off-by: Chris Zankel <chris@zankel.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/xtensa/kernel/asm-offsets.c |    1 -
 arch/xtensa/kernel/syscalls.c    |    4 ++--
 arch/xtensa/kernel/syscalls.h    |    6 +++---
 arch/xtensa/kernel/vmlinux.lds.S |    6 +++---
 ipc/util.h                       |    2 +-
 5 files changed, 9 insertions(+), 10 deletions(-)

diff -puN arch/xtensa/kernel/asm-offsets.c~xtensa-remove-old-syscalls-2-2 arch/xtensa/kernel/asm-offsets.c
--- devel/arch/xtensa/kernel/asm-offsets.c~xtensa-remove-old-syscalls-2-2	2005-07-09 14:41:47.000000000 -0700
+++ devel-akpm/arch/xtensa/kernel/asm-offsets.c	2005-07-09 14:41:47.000000000 -0700
@@ -15,7 +15,6 @@
 #include <asm/processor.h>
 
 #include <linux/types.h>
-#include <linux/sched.h>
 #include <linux/stddef.h>
 #include <linux/thread_info.h>
 #include <linux/ptrace.h>
diff -puN arch/xtensa/kernel/syscalls.c~xtensa-remove-old-syscalls-2-2 arch/xtensa/kernel/syscalls.c
--- devel/arch/xtensa/kernel/syscalls.c~xtensa-remove-old-syscalls-2-2	2005-07-09 14:41:47.000000000 -0700
+++ devel-akpm/arch/xtensa/kernel/syscalls.c	2005-07-09 14:41:47.000000000 -0700
@@ -70,8 +70,8 @@ int sys_pipe(int __user *userfds)
 /*
  * Common code for old and new mmaps.
  */
-long sys_mmap2(unsigned long addr, unsigned long len, unsigned long prot,
-	       unsigned long flags, unsigned long fd, unsigned long pgoff)
+long sys_mmap(unsigned long addr, unsigned long len, unsigned long prot,
+	      unsigned long flags, unsigned long fd, unsigned long pgoff)
 {
 	int error = -EBADF;
 	struct file * file = NULL;
diff -puN arch/xtensa/kernel/syscalls.h~xtensa-remove-old-syscalls-2-2 arch/xtensa/kernel/syscalls.h
--- devel/arch/xtensa/kernel/syscalls.h~xtensa-remove-old-syscalls-2-2	2005-07-09 14:41:47.000000000 -0700
+++ devel-akpm/arch/xtensa/kernel/syscalls.h	2005-07-09 14:41:47.000000000 -0700
@@ -42,7 +42,7 @@ SYSCALL(sys_mknod, 3)
 SYSCALL(sys_chmod, 2)			/* 15 */
 SYSCALL(sys_lchown, 3)
 SYSCALL(sys_ni_syscall, 0)
-SYSCALL(sys_stat, 2)
+SYSCALL(sys_newstat, 2)
 SYSCALL(sys_lseek, 3)
 SYSCALL(sys_getpid, 0)			/* 20 */
 SYSCALL(sys_mount, 5)
@@ -52,7 +52,7 @@ SYSCALL(sys_getuid, 0)
 SYSCALL(sys_ni_syscall, 1)		/* 25 */
 SYSCALL(sys_ptrace, 4)
 SYSCALL(sys_ni_syscall, 1)
-SYSCALL(sys_fstat, 2)
+SYSCALL(sys_newfstat, 2)
 SYSCALL(sys_ni_syscall, 0)
 SYSCALL(sys_utime, 2)			/* 30 */
 SYSCALL(sys_ni_syscall, 0)
@@ -108,7 +108,7 @@ SYSCALL(sys_getgroups, 2)		/* 80 */
 SYSCALL(sys_setgroups, 2)
 SYSCALL(sys_ni_syscall, 0)
 SYSCALL(sys_symlink, 2)
-SYSCALL(sys_lstat, 2)
+SYSCALL(sys_newlstat, 2)
 SYSCALL(sys_readlink, 3)		/* 85 */
 SYSCALL(sys_uselib, 1)
 SYSCALL(sys_swapon, 2)
diff -puN arch/xtensa/kernel/vmlinux.lds.S~xtensa-remove-old-syscalls-2-2 arch/xtensa/kernel/vmlinux.lds.S
--- devel/arch/xtensa/kernel/vmlinux.lds.S~xtensa-remove-old-syscalls-2-2	2005-07-09 14:41:47.000000000 -0700
+++ devel-akpm/arch/xtensa/kernel/vmlinux.lds.S	2005-07-09 14:41:47.000000000 -0700
@@ -90,10 +90,10 @@ SECTIONS
     *(.literal .text)
     *(.srom.text)
     VMLINUX_SYMBOL(__sched_text_start) = .;
-    *(.sched.text.literal .sched.text)
+    *(.sched.literal .sched.text)
     VMLINUX_SYMBOL(__sched_text_end) = .;
     VMLINUX_SYMBOL(__lock_text_start) = .;
-    *(.spinlock.text.literal .spinlock.text)
+    *(.spinlock.literal .spinlock.text)
     VMLINUX_SYMBOL(__lock_text_end) = .;
 
   }
@@ -164,7 +164,7 @@ SECTIONS
   __init_begin = .;
   .init.text : {
   	_sinittext = .;
-	*(.init.text.literal) *(.init.text)
+	*(.init.literal) *(.init.text)
 	_einittext = .;
   }
 
diff -puN ipc/util.h~xtensa-remove-old-syscalls-2-2 ipc/util.h
--- devel/ipc/util.h~xtensa-remove-old-syscalls-2-2	2005-07-09 14:41:47.000000000 -0700
+++ devel-akpm/ipc/util.h	2005-07-09 14:41:47.000000000 -0700
@@ -67,7 +67,7 @@ int ipc_checkid(struct ipc_ids* ids, str
 void kernel_to_ipc64_perm(struct kern_ipc_perm *in, struct ipc64_perm *out);
 void ipc64_perm_to_ipc_perm(struct ipc64_perm *in, struct ipc_perm *out);
 
-#if defined(__ia64__) || defined(__x86_64__) || defined(__hppa__)
+#if defined(__ia64__) || defined(__x86_64__) || defined(__hppa__) || defined(__XTENSA__)
   /* On IA-64, we always use the "64-bit version" of the IPC structures.  */ 
 # define ipc_parse_version(cmd)	IPC_64
 #else
_
